/*
 * This software is governed by the CeCILL-B license under French law and
 * abiding by the rules of distribution of free software. You can use, modify
 * and/ or redistribute the software under the terms of the CeCILL-B license as
 * circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and rights to copy, modify
 * and redistribute granted by the license, users are provided only with a
 * limited warranty and the software's author, the holder of the economic
 * rights, and the successive licensors have only limited liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated with
 * loading, using, modifying and/or developing or reproducing the software by
 * the user in light of its specific status of free software, that may mean that
 * it is complicated to manipulate, and that also therefore means that it is
 * reserved for developers and experienced professionals having in-depth
 * computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling
 * the security of their systems and/or data to be ensured and, more generally,
 * to use and operate it in the same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-B license and that you accept its terms.
 */

package fr.amap.lidar.amapvox.visualization.opengl.util;

import java.io.IOException;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;
import fr.amap.lidar.amapvox.visualization.opengl.resources.textures.TextureCubemap;
import fr.amap.lidar.amapvox.visualization.opengl.resources.textures.TextureFormat;

/**
 * Class to create and store skyboxes.
 */
public class Skyboxes {
    
    private static Map<String, TextureCubemap> SKIES = new LinkedHashMap();
    
    public static final void initializeSkies() throws IOException {
        SKIES.put("Simple", new TextureCubemap(
                "SimpleSky", 512, TextureFormat.RGB, true,
                "/textures/simplesky/right.png", "/textures/simplesky/left.png", 
                "/textures/simplesky/top.png", "/textures/simplesky/bottom.png", 
                "/textures/simplesky/back.png", "/textures/simplesky/front.png")
        );
        
        SKIES.put("Plain", new TextureCubemap(
                "PlainSky", 512, TextureFormat.RGB, true,
                "/textures/plainsky/right.png", "/textures/plainsky/left.png", 
                "/textures/plainsky/top.png", "/textures/plainsky/bottom.png", 
                "/textures/plainsky/back.png", "/textures/plainsky/front.png"));
        
        SKIES.put("Blizzard", new TextureCubemap(
                "BlizzardSky", 512, TextureFormat.RGB, true,
                "/textures/blizzardsky/right.png", "/textures/blizzardsky/left.png", 
                "/textures/blizzardsky/top.png", "/textures/blizzardsky/bottom.png", 
                "/textures/blizzardsky/back.png", "/textures/blizzardsky/front.png")
        );
        
        SKIES.put("Sahara", new TextureCubemap(
                "SaharaSky", 512, TextureFormat.RGB, true,
                "/textures/saharasky/right.png", "/textures/saharasky/left.png", 
                "/textures/saharasky/top.png", "/textures/saharasky/bottom.png", 
                "/textures/saharasky/back.png", "/textures/saharasky/front.png")
        );
        
        SKIES.put("Miramar", new TextureCubemap(
                "MiramarSky", 512, TextureFormat.RGB, true,
                "/textures/miramarsky/right.png", "/textures/miramarsky/left.png", 
                "/textures/miramarsky/top.png", "/textures/miramarsky/bottom.png", 
                "/textures/miramarsky/back.png", "/textures/miramarsky/front.png")
        );
    }
    
    public static final TextureCubemap getSky(final String name) throws IOException {
        if (SKIES.isEmpty()) {
            initializeSkies();
        }
        
        return SKIES.get(name);
    }
    
    public static final String[] getSkyNames() throws IOException {
        if (SKIES.isEmpty()) {
            initializeSkies();
        }
        
        final String[] names = new String[SKIES.size()];
        
        final Iterator<String> iterator = SKIES.keySet().iterator();
        int index = 0;
        
        while(iterator.hasNext()) {
            names[index] = iterator.next();
            index++;
        }
        
        return names;
    }
    
}
